==> istio-model-v1alpha3-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ConnectionPoolSettingsTCPSettingsFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConnectionPoolSettingsTCPSettingsFluentImpl<A extends ConnectionPoolSettingsTCPSettingsFluent<A>> extends BaseFluent<A> implements ConnectionPoolSettingsTCPSettingsFluent<A>{
  public ConnectionPoolSettingsTCPSettingsFluentImpl() {
  }
  public ConnectionPoolSettingsTCPSettingsFluentImpl(ConnectionPoolSettingsTCPSettings instance) {
    this.withConnectTimeout(instance.getConnectTimeout()); 
    this.withMaxConnections(instance.getMaxConnections()); 
    this.withTcpKeepalive(instance.getTcpKeepalive()); 
  }
  private String connectTimeout;
  private Integer maxConnections;
  private ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder tcpKeepalive;
  public String getConnectTimeout() {
    return this.connectTimeout;
  }
  public A withConnectTimeout(String connectTimeout) {
    this.connectTimeout=connectTimeout; return (A) this;
  }
  public Boolean hasConnectTimeout() {
    return this.connectTimeout != null;
  }
  public Integer getMaxConnections() {
    return this.maxConnections;
  }
  public A withMaxConnections(Integer maxConnections) {
    this.maxConnections=maxConnections; return (A) this;
  }
  public Boolean hasMaxConnections() {
    return this.maxConnections != null;
  }
  
  /**
   * This method has been deprecated, please use method buildTcpKeepalive instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConnectionPoolSettingsTCPSettingsTcpKeepalive getTcpKeepalive() {
    return this.tcpKeepalive!=null ?this.tcpKeepalive.build():null;
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepalive buildTcpKeepalive() {
    return this.tcpKeepalive!=null ?this.tcpKeepalive.build():null;
  }
  public A withTcpKeepalive(ConnectionPoolSettingsTCPSettingsTcpKeepalive tcpKeepalive) {
    _visitables.get("tcpKeepalive").remove(this.tcpKeepalive);
    if (tcpKeepalive!=null){ this.tcpKeepalive= new ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(tcpKeepalive); _visitables.get("tcpKeepalive").add(this.tcpKeepalive);} else { this.tcpKeepalive = null; _visitables.get("tcpKeepalive").remove(this.tcpKeepalive); } return (A) this;
  }
  public Boolean hasTcpKeepalive() {
    return this.tcpKeepalive != null;
  }
  public A withNewTcpKeepalive(String interval,Integer probes,String time) {
    return (A)withTcpKeepalive(new ConnectionPoolSettingsTCPSettingsTcpKeepalive(interval, probes, time));
  }
  public ConnectionPoolSettingsTCPSettingsFluent.TcpKeepaliveNested<A> withNewTcpKeepalive() {
    return new ConnectionPoolSettingsTCPSettingsFluentImpl.TcpKeepaliveNestedImpl();
  }
  public ConnectionPoolSettingsTCPSettingsFluent.TcpKeepaliveNested<A> withNewTcpKeepaliveLike(ConnectionPoolSettingsTCPSettingsTcpKeepalive item) {
    return new ConnectionPoolSettingsTCPSettingsFluentImpl.TcpKeepaliveNestedImpl(item);
  }
  public ConnectionPoolSettingsTCPSettingsFluent.TcpKeepaliveNested<A> editTcpKeepalive() {
    return withNewTcpKeepaliveLike(getTcpKeepalive());
  }
  public ConnectionPoolSettingsTCPSettingsFluent.TcpKeepaliveNested<A> editOrNewTcpKeepalive() {
    return withNewTcpKeepaliveLike(getTcpKeepalive() != null ? getTcpKeepalive(): new ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder().build());
  }
  public ConnectionPoolSettingsTCPSettingsFluent.TcpKeepaliveNested<A> editOrNewTcpKeepaliveLike(ConnectionPoolSettingsTCPSettingsTcpKeepalive item) {
    return withNewTcpKeepaliveLike(getTcpKeepalive() != null ? getTcpKeepalive(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConnectionPoolSettingsTCPSettingsFluentImpl that = (ConnectionPoolSettingsTCPSettingsFluentImpl) o;
    if (connectTimeout != null ? !connectTimeout.equals(that.connectTimeout) :that.connectTimeout != null) return false;
    if (maxConnections != null ? !maxConnections.equals(that.maxConnections) :that.maxConnections != null) return false;
    if (tcpKeepalive != null ? !tcpKeepalive.equals(that.tcpKeepalive) :that.tcpKeepalive != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(connectTimeout,  maxConnections,  tcpKeepalive,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (connectTimeout != null) { sb.append("connectTimeout:"); sb.append(connectTimeout + ","); }
    if (maxConnections != null) { sb.append("maxConnections:"); sb.append(maxConnections + ","); }
    if (tcpKeepalive != null) { sb.append("tcpKeepalive:"); sb.append(tcpKeepalive); }
    sb.append("}");
    return sb.toString();
  }
  class TcpKeepaliveNestedImpl<N> extends ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl<ConnectionPoolSettingsTCPSettingsFluent.TcpKeepaliveNested<N>> implements ConnectionPoolSettingsTCPSettingsFluent.TcpKeepaliveNested<N>,Nested<N>{
    TcpKeepaliveNestedImpl(ConnectionPoolSettingsTCPSettingsTcpKeepalive item) {
      this.builder = new ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(this, item);
    }
    TcpKeepaliveNestedImpl() {
      this.builder = new ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(this);
    }
    ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder builder;
    public N and() {
      return (N) ConnectionPoolSettingsTCPSettingsFluentImpl.this.withTcpKeepalive(builder.build());
    }
    public N endTcpKeepalive() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ConnectionPoolSettingsTCPSettingsFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConnectionPoolSettingsTCPSettingsFluentImpl<A extends ConnectionPoolSettingsTCPSettingsFluent<A>> extends BaseFluent<A> implements ConnectionPoolSettingsTCPSettingsFluent<A>{
  public ConnectionPoolSettingsTCPSettingsFluentImpl() {
  }
  public ConnectionPoolSettingsTCPSettingsFluentImpl(ConnectionPoolSettingsTCPSettings instance) {
    if (instance != null) {
      this.withConnectTimeout(instance.getConnectTimeout());
      this.withMaxConnections(instance.getMaxConnections());
      this.withTcpKeepalive(instance.getTcpKeepalive());
    }
  }
  private String connectTimeout;
  private Integer maxConnections;
  private ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder tcpKeepalive;
  public String getConnectTimeout() {
    return this.connectTimeout;
  }
  public A withConnectTimeout(String connectTimeout) {
    this.connectTimeout=connectTimeout; return (A) this;
  }
  public Boolean hasConnectTimeout() {
    return this.connectTimeout != null;
  }
  public Integer getMaxConnections() {
    return this.maxConnections;
  }
  public A withMaxConnections(Integer maxConnections) {
    this.maxConnections=maxConnections; return (A) this;
  }
  public Boolean hasMaxConnections() {
    return this.maxConnections != null;
  }
  
  /**
   * This method has been deprecated, please use method buildTcpKeepalive instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConnectionPoolSettingsTCPSettingsTcpKeepalive getTcpKeepalive() {
    return this.tcpKeepalive!=null ?this.tcpKeepalive.build():null;
  }
  public ConnectionPoolSettingsTCPSettingsTcpKeepalive buildTcpKeepalive() {
    return this.tcpKeepalive!=null ?this.tcpKeepalive.build():null;
  }
  public A withTcpKeepalive(ConnectionPoolSettingsTCPSettingsTcpKeepalive tcpKeepalive) {
    _visitables.get("tcpKeepalive").remove(this.tcpKeepalive);
    if (tcpKeepalive!=null){ this.tcpKeepalive= new ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(tcpKeepalive); _visitables.get("tcpKeepalive").add(this.tcpKeepalive);} else { this.tcpKeepalive = null; _visitables.get("tcpKeepalive").remove(this.tcpKeepalive); } return (A) this;
  }
  public Boolean hasTcpKeepalive() {
    return this.tcpKeepalive != null;
  }
  public A withNewTcpKeepalive(String interval,Integer probes,String time) {
    return (A)withTcpKeepalive(new ConnectionPoolSettingsTCPSettingsTcpKeepalive(interval, probes, time));
  }
  public ConnectionPoolSettingsTCPSettingsFluentImpl.TcpKeepaliveNested<A> withNewTcpKeepalive() {
    return new ConnectionPoolSettingsTCPSettingsFluentImpl.TcpKeepaliveNestedImpl();
  }
  public ConnectionPoolSettingsTCPSettingsFluentImpl.TcpKeepaliveNested<A> withNewTcpKeepaliveLike(ConnectionPoolSettingsTCPSettingsTcpKeepalive item) {
    return new ConnectionPoolSettingsTCPSettingsFluentImpl.TcpKeepaliveNestedImpl(item);
  }
  public ConnectionPoolSettingsTCPSettingsFluentImpl.TcpKeepaliveNested<A> editTcpKeepalive() {
    return withNewTcpKeepaliveLike(getTcpKeepalive());
  }
  public ConnectionPoolSettingsTCPSettingsFluentImpl.TcpKeepaliveNested<A> editOrNewTcpKeepalive() {
    return withNewTcpKeepaliveLike(getTcpKeepalive() != null ? getTcpKeepalive(): new ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder().build());
  }
  public ConnectionPoolSettingsTCPSettingsFluentImpl.TcpKeepaliveNested<A> editOrNewTcpKeepaliveLike(ConnectionPoolSettingsTCPSettingsTcpKeepalive item) {
    return withNewTcpKeepaliveLike(getTcpKeepalive() != null ? getTcpKeepalive(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConnectionPoolSettingsTCPSettingsFluentImpl that = (ConnectionPoolSettingsTCPSettingsFluentImpl) o;
    if (!java.util.Objects.equals(connectTimeout, that.connectTimeout)) return false;

    if (!java.util.Objects.equals(maxConnections, that.maxConnections)) return false;

    if (!java.util.Objects.equals(tcpKeepalive, that.tcpKeepalive)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(connectTimeout,  maxConnections,  tcpKeepalive,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (connectTimeout != null) { sb.append("connectTimeout:"); sb.append(connectTimeout + ","); }
    if (maxConnections != null) { sb.append("maxConnections:"); sb.append(maxConnections + ","); }
    if (tcpKeepalive != null) { sb.append("tcpKeepalive:"); sb.append(tcpKeepalive); }
    sb.append("}");
    return sb.toString();
  }
  class TcpKeepaliveNestedImpl<N> extends ConnectionPoolSettingsTCPSettingsTcpKeepaliveFluentImpl<ConnectionPoolSettingsTCPSettingsFluentImpl.TcpKeepaliveNested<N>> implements ConnectionPoolSettingsTCPSettingsFluentImpl.TcpKeepaliveNested<N>,Nested<N>{
    TcpKeepaliveNestedImpl(ConnectionPoolSettingsTCPSettingsTcpKeepalive item) {
      this.builder = new ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(this, item);
    }
    TcpKeepaliveNestedImpl() {
      this.builder = new ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder(this);
    }
    ConnectionPoolSettingsTCPSettingsTcpKeepaliveBuilder builder;
    public N and() {
      return (N) ConnectionPoolSettingsTCPSettingsFluentImpl.this.withTcpKeepalive(builder.build());
    }
    public N endTcpKeepalive() {
      return and();
    }
    
  }
  
}
